@@ -2,16 +2,18 @@
 from flask import Flask, url_for
 from flaskext.frozen import Freezer
 
-from .admin import admin_module
+from .admin import admin_blueprint
 
 
-def init_app(defer_init_app=False):
+def create_app(defer_init_app=False, freezer_kwargs=None):
     app = Flask(__name__)
-    app.register_module(admin_module, url_prefix='/admin')
+    app.register_blueprint(admin_blueprint, url_prefix='/admin')
+    if not freezer_kwargs:
+        freezer_kwargs = {}
     if defer_init_app:
-        freezer = Freezer()
+        freezer = Freezer(**freezer_kwargs)
     else:
-        freezer = Freezer(app)
+        freezer = Freezer(app, **freezer_kwargs)
 
     @app.route('/')
     def index():
@@ -19,6 +21,8 @@ def init_app(defer_init_app=False):
 
     @app.route('/page/<name>/')
     def page(name):
+        url_for('product', product_id='3')  # Pretend we’re adding a link
+        url_for('product', product_id='4')  # Another link
         return u'Hello\xa0World! ' + name
 
     @app.route('/where_am_i/')
@@ -44,11 +48,10 @@ def init_app(defer_init_app=False):
         yield {'product_id': 1}
         # single string: url
         yield '/product_2/'
-        
+
         yield 'page', {'name': u'I løvë Unicode'}
-    
+
     if defer_init_app:
         freezer.init_app(app)
 
     return app, freezer
-
